<?php

declare(strict_types=1);

namespace Drupal\hebdate\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Kfirba\Formats\Format;
use Kfirba\GregorianDate;

/**
 * Plugin implementation of the 'Hebrew date' formatter.
 *
 * @FieldFormatter(
 *   id = "hebdate_hebrew_date",
 *   label = @Translation("Hebrew date"),
 *   field_types = {"date", "datetime"},
 * )
 */
final class HebrewDateFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $element = [];
    foreach ($items as $delta => $date) {
      $date = new \DateTime($date->value);
      $hebrew_date = GregorianDate::toJewish($date)->format(Format::PRESENTABLE_HEBREW_DATE)->convert();
      $element[$delta] = [
        '#markup' => $hebrew_date,
      ];

    }
    return $element;
  }

}
