<?php

declare(strict_types=1);

namespace Drupal\hebdate\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Kfirba\Formats\Format;
use Kfirba\GregorianDate;

/**
 * Plugin implementation of the 'Hebrew date' formatter.
 *
 * @FieldFormatter(
 *   id = "hebdate_hebrew_daterange",
 *   label = @Translation("Hebrew daterange"),
 *   field_types = {"daterange",},
 * )
 */
final class HebrewDateRangeFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $element = [];
    foreach ($items as $delta => $item) {
      if (!empty($item->start_date) && !empty($item->end_date)) {
        /** @var \Drupal\Core\Datetime\DrupalDateTime $start_date */
        $start_date = new \DateTime($item->start_date->__toString());
        $hebrew_start_date = GregorianDate::toJewish($start_date)->format(Format::PRESENTABLE_HEBREW_DATE)->convert();
        /** @var \Drupal\Core\Datetime\DrupalDateTime $end_date */
        $end_date = new \DateTime($item->end_date->__toString());
        $hebrew_end_date = GregorianDate::toJewish($end_date)->format(Format::PRESENTABLE_HEBREW_DATE)->convert();

        $element[$delta] = [
          '#markup' => $this->t('@start - @end', [
            '@start' => $hebrew_start_date,
            '@end' => $hebrew_end_date,
          ]),
        ];
      }
    }
    return $element;
  }

}
